Learn R Programming

cancerR (version 0.1.0)

kid_class: Classification of childhood cancer.

Description

Determines the type of childhood cancer cases based on the histology and site codes of the cancer. It uses the International Classification of Childhood Cancer (ICCC) codes to determine the classification. The function returns a value based on the method specified and the depth level of the classification hierarchy to be determined.

Usage

kid_class(histology, site, method = "iccc3", depth = 1, verbose = FALSE)

Value

Returns the diagnostic classification of the childhood cancer based on the specified method and depth level.

Arguments

histology

Histology code of the cancer.

site

Site (aka topography) code of the cancer.

method

Method to use for diagnosis classification. Default is "iccc3". Can be one of "iccc3", "who-iccc3", "iarc2017".

depth

Depth level of the classification hierarchy to be determined. If set to 99, will return the SEER grouping.

verbose

Logical value to print messages to the console if unable to classify or duplicates found. Default is FALSE.

Examples

Run this code
kid_class("8522", "C50.1", method = "iccc3", depth = 1)

kid_class("8970", "C22.0", method = "iccc3", depth = 2)

Run the code above in your browser using DataLab